share_my_apk library
A library to build and upload Flutter Android APKs.
Classes
- ApkOrganizerService
- A service for organizing and renaming built APK files.
- ApkParserService
-
A service for parsing the output of the
flutter build apkcommand to find the path to the generated APK file. - ArgParserUtil
- A utility class for parsing command-line arguments.
- CliOptions
- Configuration model for command-line interface options.
- ConfigService
-
Service for reading configuration from
share_my_apk.yaml. - DiawiUploadService
- An UploadService for uploading APKs to Diawi.
- FirebaseCliUploadService
- Upload service for Firebase App Distribution using Firebase CLI.
- FlutterBuildService
- GofileUploadService
- An UploadService for uploading APKs to Gofile.io.
- HelpUtil
- InitUtil
- RetryConditions
- Common retry conditions for different types of operations.
- RetryUtil
- A utility class for implementing retry logic with exponential backoff.
- UploadService
- An abstract class that defines the interface for an upload service.
- UploadServiceFactory
- A factory for creating UploadService instances.
Exceptions / Errors
- BuildException
- Exception thrown when an APK build fails.
- UploadException
- Exception thrown when an APK upload fails.